@@ -21,7 +21,7 @@ our ( $VERSION, $COMPATIBLE, $FILENAME );
 
 
 # $VERSION is also in Parse/Eyapp.pm
-$VERSION = "1.149";
+$VERSION = "1.150";
 $COMPATIBLE = '0.07';
 $FILENAME   =__FILE__;
 
@@ -29,7 +29,7 @@ use Carp;
 use Scalar::Util qw{reftype looks_like_number};
 
 #Known parameters, all starting with YY (leading YY will be discarded)
-my(%params)=(YYLEX => 'CODE', 'YYERROR' => 'CODE', YYVERSION => '',
+my (%params)=(YYLEX => 'CODE', 'YYERROR' => 'CODE', YYVERSION => '',
        YYRULES => 'ARRAY', YYSTATES => 'ARRAY', YYDEBUG => '', 
        # added by Casiano
        #YYPREFIX  => '',  # Not allowed at YYParse time but in new
@@ -43,7 +43,7 @@ my(%params)=(YYLEX => 'CODE', 'YYERROR' => 'CODE', YYVERSION => '',
 my (%newparams) = (%params, YYPREFIX => '',);
 
 #Mandatory parameters
-my(@params)=('LEX','RULES','STATES');
+my (@params)=('LEX','RULES','STATES');
 
 sub new {
     my($class)=shift;
@@ -51,7 +51,6 @@ sub new {
     my($errst,$nberr,$token,$value,$check,$dotpos);
 
     my($self)={ 
-      ERROR => \&_Error,
       ERRST => \$errst,
       NBERR => \$nberr,
       TOKEN => \$token,
@@ -60,7 +59,7 @@ sub new {
       STACK => [],
       DEBUG => 0,
       PREFIX => "",
-      CHECK => \$check 
+      CHECK => \$check, 
     };
 
   _CheckParams( [], \%newparams, \@_, $self );
@@ -74,7 +73,25 @@ sub new {
         ref($class)
     and $class=ref($class);
 
-    bless($self,$class);
+    unless($self->{ERROR}) {
+      if ($class->isa('Parse::Eyapp::TailSupport')) {
+        $self->{ERROR} = $class->error;
+      }
+      else {
+        $self->{ERROR} = \&_Error;
+      }
+    }
+
+    unless($self->{LEX}) {
+      if ($class->isa('Parse::Eyapp::TailSupport')) {
+        $self->{LEX} = $class->lexer;
+        @params = ('RULES','STATES');
+      }
+    }
+
+    my $parser = bless($self,$class);
+
+    $parser;
 }
 
 sub YYParse {
@@ -936,6 +953,13 @@ sub YYCurval {
   }
 }
 
+sub expects {
+  my $self = shift;
+  my $token = shift;
+
+  return grep { $_ eq $token } $self->YYExpect;
+}
+
 #sub YYExpect {
 #    my($self)=shift;
 #
@@ -943,8 +967,9 @@ sub YYCurval {
 #}
 
 sub YYLexer {
-    my($self)=shift;
+  my($self)=shift;
 
+  $$self{LEX} = shift if @_;
   $$self{LEX};
 }
 
